#
# spec file for package nlopt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}

%if "%{flavor}" == ""
%bcond_with    bindings
%endif
%if "%{flavor}" == "bindings"
%bcond_without bindings
%define psuffix -bindings
%endif
%define pname nlopt

Name:           nlopt%{?psuffix}
Version:        2.7.1
Release:        bp154.1.65
Summary:        A library for nonlinear optimization
License:        LGPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://nlopt.readthedocs.io/en/latest/
Source0:        https://github.com/stevengj/nlopt/archive/v%{version}.tar.gz#/%{pname}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  pkgconfig
%if %{with bindings}
BuildRequires:  python3-numpy-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(octave)
%endif

%description
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package     -n lib%{pname}0
Summary:        A library for nonlinear optimization
Group:          System/Libraries

%description -n lib%{pname}0
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package        devel
Summary:        Development files for %{pname}
Group:          Development/Libraries/C and C++
Requires:       lib%{pname}0 = %{version}

%description    devel
The %{pname}-devel package contains libraries and header files for
developing applications that use NLopt.

%package     -n python3-%{pname}
Summary:        Python interface to nonlinear optimization libray
Group:          Development/Libraries/Python
Requires:       python3-numpy
Provides:       python-%{pname} = %{version}-%{release}
Obsoletes:      python-%{pname} < %{version}-%{release}


%description -n python3-%{pname}
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains the Python3 interface for NLopt.

%package     -n octave-nlopt_optimize
Summary:        Octave interface to nonlinear optimization libray
Group:          Productivity/Scientific/Math
%requires_eq    octave-cli

%description -n octave-nlopt_optimize
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains the Octave interface for NLopt.

%prep
%autosetup -p1 -n %{pname}-%{version}

%build
%cmake \
   -DCMAKE_SKIP_RPATH:BOOL=OFF \
   -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
   -DNLOPT_MATLAB=OFF \
   -DNLOPT_CXX:BOOL=ON \
   -DNLOPT_TESTS:BOOL=ON \
   %{!?with_bindings:-DNLOPT_PYTHON:BOOL=OFF} \
   %{!?with_bindings:-DNLOPT_OCTAVE:BOOL=OFF} \
   %{!?with_bindings:-DNLOPT_SWIG:BOOL=OFF} \
   %{nil}
%cmake_build

%install
%cmake_install
%if %{with bindings}
# remove files from the main package
for e in %{_includedir} %{_libdir}/lib\* %{_libdir}/pkgconfig %{_libdir}/cmake %{_mandir} ; do
    rm -R %{buildroot}/${e}
done
%fdupes %{buildroot}%{pyton3_sitearch}
%endif

%check
%ctest

%post -n lib%{pname}0 -p /sbin/ldconfig
%postun -n lib%{pname}0 -p /sbin/ldconfig

%if "%{flavor}" == ""
%files -n lib%{pname}0
%{_libdir}/*.so.*

%files devel
%license COPYING
%doc AUTHORS NEWS.md README.md TODO
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{pname}.pc
%{_libdir}/cmake/%{pname}/
%{_mandir}/man3/*.3%{?ext_man}
%endif

%if %{with bindings}
%files -n python3-%{pname}
%license COPYING
%{python3_sitearch}/*

%files -n octave-nlopt_optimize
%license COPYING
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%{_datadir}/octave/*/site/m/*
%endif

%changelog
* Tue Feb  8 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split bindings into separate build, to avoid the octave (and
  thus Java, Qt5, ...) dependency. Also allows to build the
  library on SLE 15.x.
- Adjust Python3 package name (python-nlopt -> python3-nlopt)
* Tue Dec  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.7.1:
  * Various minor bugfixes (gh#stevengj/nlopt#268,
    gh#stevengj/nlopt#409, gh#stevengj/nlopt#420)
  * Build improvements (support Octave 6.x, Guile 3.x, Cmake 3.2).
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.7.0:
  * New nlopt_set_param API for setting internal algorithm
    parameters (gh#stevengj/nlopt#365).
  * Avoid library-symbol conflicts (gh#stevengj/nlopt#355,
    gh#stevengj/nlopt#361)
- Run tests using ctest as part of %%check section.
- Handle erroneous RPATH in openSUSE:Leap:15.2's %%cmake macro by
  explicitly setting CMAKE_SKIP_RPATH to OFF and
  CMAKE_SKIP_INSTALL_RPATH to ON; while only required for 15.2,
  setting these for all versions doesn't hurt.
* Sun Apr 26 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to verion 2.6.2:
  * Fixed forced stop exception with dimension elimination
    (gh#stevengj/nlopt#317).
  * Fixed get_initial_step wrapping (gh#stevengj/nlopt#319).
  * Various build fixes (gh#stevengj/nlopt#314,
    gh#stevengj/nlopt#308, gh#stevengj/nlopt#303,
    gh#stevengj/nlopt#278).
- Rename source tarball into %%{name}-%%{version} format.
* Mon Apr 15 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6.1:
  * Fix nlopt_version return value for 2.6.x and update soname and
    docs.
- Changes from version 2.6.0:
  * New set_upper_bound and set_lower_bound functions in the
    low-level C API to set one bound at a time
    (gh#stevengi/nlopt#257).
  * There is no longer a separate libnlopt_cxx library — C++
    algorithms (stogo) are compiled and included by default
    (gh#stevengi/nlopt#198).
  * Bug fixes:
  * gh#stevengi/nlopt#197
  * gh#stevengi/nlopt#216
  * gh#stevengi/nlopt#245
  * gh#stevengi/nlopt#250
  * gh#stevengi/nlopt#230
  * gh#stevengi/nlopt#261
  * gh#stevengi/nlopt#242
  * gh#stevengi/nlopt#258.
- Drop patches incorporated upstream:
  * nlopt-octave-5.0.patch
  * nlopt-cmake-3.13.patch.
* Sat Mar 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5.0:
  * New AGS global solver (gh#stevengj/nlopt#194).
  * New `nlopt_get_numevals` function providing a built-in
    evaluation counter (gh#stevengj/nlopt#160).
  * New `nlopt_get_errmsg` function for more descriptive error
    messages.
  * Build system is converted to `cmake` (gh#stevengj/nlopt#49).
  * Plugins updated for recent Octave and Guile versions.
  * Various other build fixes and minor bug fixes.
- Drop patches already incorporated upstream or otherwise fixed:
  * nlopt-2.3-pkgconfig.patch
  * pythondir.patch
  * nlopt-octave-4.0.patch
  * nlopt-octave4.4-prefixdir.patch
  * nlopt-octave4.4-do_multi_index_op.patch
- New patches:
  * nlopt-octave-5.0.patch: Fix compilation and running against
    octave >= 5.0; patch taken from upstream git commit.
  * nlopt-cmake-3.13.patch: Fix building python module when using
    cmake 3.13+; patch taken from upstream git commit and rebased
    to apply cleanly.
- Switch to building python3 modules instead of python2.
- Switch to cmake build system in keeping with upstream; introduce
  BuildRequires: cmake and drop libtool.
- New BuildRequires: swig needed to build python module.
- Use %%%%autosetup to setup build directory and apply patches.
* Sat Jun  2 2018 badshah400@gmail.com
- Add patches to fix compilation against octave 4.4:
  * nlopt-octave4.4-prefixdir.patch: Fix how to find octave's
    prefix dir in configure.ac: octave-config no longer supports
    the keyword PREFIX and uses OCTAVE_HOME in its stead; patch
    being sent upstream. Add BuildRequires: libtool and regenerate
    build files (autoreconf -fvi) before configuring build.
  * nlopt-octave4.4-do_multi_index_op.patch: Replace
    do_multi_index_op by feval; the former is dropped from octave
    4.4; patch being sent upstream.
- Package python modules installed to sitelib as well.
* Thu Jun 23 2016 badshah400@gmail.com
- Use %%requires_eq octave-cli instead of Requires, octave installs
  its files to versioned dirs, so it is important for nlopt to
  be rebuilt for every version update of octave. Making the
  Requires version dependent achieves this.
* Tue Nov 17 2015 dmitry_r@opensuse.org
- Fix compatibility with Octave 4.0
  * nlopt-octave-4.0.patch
* Sun May 31 2015 dmitry_r@opensuse.org
- Disable Octave module due to incompatibility with Octave 4.0
* Thu Nov 13 2014 dmitry_r@opensuse.org
- Update to version 2.4.2
  * Bugfix release, see included NEWS file for details.
- Update package descriptionts.
* Tue Feb 11 2014 badshah400@gmail.com
- Update to version 2.4.1
  - No Linux relevant changes from version 2.4.0
- Changes from version 2.4.0:
  + New genetic algorithm ESCH
  + Fix swig dir for VPATH builds
  + Use python-config program in the configure script to find the
    include directories for Python, if possible (may be overridden
    by PYTHON_CONFIG environment variable)
  + Bugfix in copy constructor for C++ and Python interfaces
  + Bugfix in return value for setting min/max objective
  + Handle negative rescalings in COBYLA and BOBYQA
  + Plugin installation honors the configure --prefix, if any
  + Various compilation fixes for compatibility with recent
    software
- Packaging changes:
  + Minor rebase of pythondir.patch
  + Drop nlopt-2.3-no-return-in-nonvoid-function.patch: corrected
    upstream.
* Tue Sep 10 2013 dvaleev@suse.com
- install python parts to sitearch (pythondir.patch)
* Wed Jun 12 2013 tchvatal@suse.com
- Add fix for .pc file so we can use this library even
  with other projects.
  * nlopt-2.3-pkgconfig.patch
* Sun Feb 24 2013 scorot@free.fr
- remove %%%%clean section
- add minimal single-line comment in spec file for patch0
- add files on %%%%doc section
- spec file cleanup
- add python(abi) requirements recent recent products
- update source url
* Sun Aug 19 2012 scorot@free.fr
- again fix build on x86_64
* Sun Aug 19 2012 scorot@free.fr
- fix build on x86_64
- fix package group names
* Sun Aug 19 2012 scorot@free.fr
- first package
